"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault")["default"];
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _vue = require("vue");
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _unified = require("unified");
var _rehypePrismPlus = _interopRequireDefault(require("rehype-prism-plus"));
var _rehypeAttr = _interopRequireDefault(require("rehype-attr"));
var _remarkGfm = _interopRequireDefault(require("remark-gfm"));
var _rehypeRaw = _interopRequireDefault(require("rehype-raw"));
var _rehypeSlug = _interopRequireDefault(require("rehype-slug"));
var _rehypeRewrite = _interopRequireDefault(require("rehype-rewrite"));
var _rehypeAutolinkHeadings = _interopRequireDefault(require("rehype-autolink-headings"));
var _remarkParse = _interopRequireDefault(require("remark-parse"));
var _remarkRehype = _interopRequireDefault(require("remark-rehype"));
var _vfile = require("vfile");
var _propertyInformation = require("property-information");
var _octiconLink = require("./nodes/octiconLink");
var _copyElement = require("./nodes/copyElement");
var _astToVue = require("./utils/ast-to-vue");
var _uriTransformer = require("./utils/uri-transformer");
var _aliasLanguage = _interopRequireDefault(require("./plugins/aliasLanguage"));
var markdownPreview = {
  rehypePlugins: {
    type: Object,
    "default": []
  },
  remarkPlugins: {
    type: Object,
    "default": []
  },
  components: {
    type: Object,
    "default": {}
  },
  source: {
    type: String,
    "default": ''
  },
  sourcePos: {
    type: Boolean,
    "default": false
  },
  rawSourcePos: {
    type: Boolean,
    "default": false
  },
  includeElementIndex: {
    type: Boolean,
    "default": false
  },
  skipHtml: {
    type: Boolean,
    "default": false
  },
  linkTarget: {
    type: [Function, String]
  },
  transformLinkUri: {
    type: Function,
    "default": _uriTransformer.uriTransformer
  },
  transformImageUri: {
    type: Function,
    "default": _uriTransformer.uriTransformer
  }
};
var getCodeStr = function getCodeStr() {
  var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  var code = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
  data.forEach(function (node) {
    if (node.type === 'text') {
      code += node.value;
    } else if (node.type === 'element' && node.children && Array.isArray(node.children)) {
      code += getCodeStr(node.children);
    }
  });
  return code;
};
var _default = exports["default"] = (0, _vue.defineComponent)({
  name: 'MarkdownPreview',
  props: markdownPreview,
  setup: function setup(props, _ref) {
    var slots = _ref.slots;
    var remarkPlugins = props.remarkPlugins,
      rehypePlugins = props.rehypePlugins;
    function processor() {
      return (0, _unified.unified)().use(_remarkParse["default"]).use(_remarkGfm["default"]).use(remarkPlugins || []).use(_remarkRehype["default"], {
        allowDangerousHtml: true
      }).use(_rehypeAttr["default"], {
        properties: 'attr'
      }).use(_rehypeRaw["default"]).use(_aliasLanguage["default"]).use(_rehypeSlug["default"]).use(_rehypeAutolinkHeadings["default"]).use(_rehypePrismPlus["default"], {
        ignoreMissing: true
      }).use(_rehypeRewrite["default"], {
        rewrite: function rewrite(node) {
          if (node.type == 'element' && /h(1|2|3|4|5|6)/.test(node.tagName) && node.children && Array.isArray(node.children) && node.children.length > 0) {
            var child = node.children[0];
            if (child && child.type === 'element' && child.properties) {
              child.properties = (0, _objectSpread2["default"])({
                className: 'anchor'
              }, child.properties);
              child.children = [(0, _octiconLink.octiconLink)()];
            }
          }
          if (node.type === 'element' && node.tagName === 'pre') {
            var code = getCodeStr(node.children);
            node.children.push((0, _copyElement.copyElement)(code));
          }
        }
      }).use(rehypePlugins || []);
    }
    return function () {
      var children = slots && slots["default"] ? slots["default"]().filter(function (item) {
        return item.type === _vue.Text;
      }).map(function (item) {
        return item.children;
      }) : [];
      var file = new _vfile.VFile();
      file.value = children && children.length > 0 ? children.join() : props.source;
      var prc = processor();
      var hastNode = prc.runSync(prc.parse(file), file);
      if (hastNode.type !== 'root') {
        throw new TypeError('Expected a `root` node');
      }
      var result = (0, _vue.h)(_vue.Fragment, {}, (0, _astToVue.childrenToVue)(hastNode, {
        listDepth: 0,
        schema: _propertyInformation.html,
        components: props.components,
        sourcePos: props.sourcePos,
        rawSourcePos: props.rawSourcePos,
        includeElementIndex: props.includeElementIndex,
        skipHtml: props.skipHtml,
        linkTarget: props.linkTarget,
        transformLinkUri: props.transformLinkUri,
        transformImageUri: props.transformImageUri
      }));
      return (0, _vue.createVNode)("div", {
        "class": "markdown-body"
      }, [result]);
    };
  }
});
module.exports = exports.default;